pub struct WebSocketSession { /* private fields */ }Expand description
Our websocket wrapper
Implementations
Sourceimpl WebSocketSession
impl WebSocketSession
pub fn new( ctx: ConnectionContext, tx: UnboundedSender<WebSocketMessage>, ) -> Self
Sourcepub fn send(
&self,
message: WebSocketMessage,
) -> Result<(), SendError<WebSocketMessage>>
pub fn send( &self, message: WebSocketMessage, ) -> Result<(), SendError<WebSocketMessage>>
Send message to the web socket connection
Sourcepub fn channel(&self) -> UnboundedSender<WebSocketMessage>
pub fn channel(&self) -> UnboundedSender<WebSocketMessage>
Provides a Sender channel to send messages to the web socket connection
Sourcepub fn context(&self) -> &ConnectionContext
pub fn context(&self) -> &ConnectionContext
Returns the http request context for this web socket connection